Documentation
¶
Index ¶
- type AlertNotification
- type Client
- func (c *Client) AlertNotification(id int64) (*AlertNotification, error)
- func (c *Client) CreateUserForm(email string, login string, name string, password string) error
- func (c *Client) Dashboard(slug string) (*Dashboard, error)
- func (c *Client) DataSource(id int64) (*DataSource, error)
- func (c *Client) DeleteAlertNotification(id int64) error
- func (c *Client) DeleteDashboard(slug string) error
- func (c *Client) DeleteDataSource(id int64) error
- func (c *Client) DeleteOrg(id int64) error
- func (c *Client) DeleteUser(id int64) error
- func (c *Client) GetAllDataSources() ([]*DataSource, error)
- func (c *Client) NewAlertNotification(a *AlertNotification) (int64, error)
- func (c *Client) NewDataSource(s *DataSource) (int64, error)
- func (c *Client) NewOrg(name string) error
- func (c *Client) Orgs() ([]Org, error)
- func (c *Client) SaveDashboard(model map[string]interface{}, overwrite bool) (*DashboardSaveResponse, error)
- func (c *Client) UpdateAlertNotification(a *AlertNotification) error
- func (c *Client) UpdateDataSource(s *DataSource) error
- func (c *Client) Users() ([]User, error)
- type Dashboard
- type DashboardMeta
- type DashboardSaveResponse
- type DataSource
- type JSONData
- type Org
- type SecureJSONData
- type User
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AlertNotification ¶
type Client ¶
func New ¶
New creates a new grafana client auth can be in user:pass format, or it can be an api key
func (*Client) AlertNotification ¶
func (c *Client) AlertNotification(id int64) (*AlertNotification, error)
func (*Client) CreateUserForm ¶
func (*Client) DataSource ¶
func (c *Client) DataSource(id int64) (*DataSource, error)
func (*Client) DeleteAlertNotification ¶
func (*Client) DeleteDashboard ¶
func (*Client) DeleteDataSource ¶
func (*Client) DeleteUser ¶
func (*Client) GetAllDataSources ¶
func (c *Client) GetAllDataSources() ([]*DataSource, error)
func (*Client) NewAlertNotification ¶
func (c *Client) NewAlertNotification(a *AlertNotification) (int64, error)
func (*Client) NewDataSource ¶
func (c *Client) NewDataSource(s *DataSource) (int64, error)
func (*Client) SaveDashboard ¶
func (c *Client) SaveDashboard(model map[string]interface{}, overwrite bool) (*DashboardSaveResponse, error)
func (*Client) UpdateAlertNotification ¶
func (c *Client) UpdateAlertNotification(a *AlertNotification) error
func (*Client) UpdateDataSource ¶
func (c *Client) UpdateDataSource(s *DataSource) error
type Dashboard ¶
type Dashboard struct {
Meta DashboardMeta `json:"meta"`
Model map[string]interface{} `json:"dashboard"`
}
type DashboardMeta ¶
type DashboardSaveResponse ¶
type DataSource ¶
type DataSource struct {
Id int64 `json:"id,omitempty"`
Name string `json:"name"`
Type string `json:"type"`
URL string `json:"url"`
Access string `json:"access"`
Database string `json:"database,omitempty"`
User string `json:"user,omitempty"`
Password string `json:"password,omitempty"`
OrgId int64 `json:"orgId,omitempty"`
IsDefault bool `json:"isDefault"`
BasicAuth bool `json:"basicAuth"`
BasicAuthUser string `json:"basicAuthUser,omitempty"`
BasicAuthPassword string `json:"basicAuthPassword,omitempty"`
JSONData JSONData `json:"jsonData,omitempty"`
SecureJSONData SecureJSONData `json:"secureJsonData,omitempty"`
}
type JSONData ¶
type JSONData struct {
AuthType string `json:"authType,omitempty"`
DefaultRegion string `json:"defaultRegion,omitempty"`
}
JSONData is a representation of the datasource `jsonData` property
type SecureJSONData ¶
type SecureJSONData struct {
AccessKey string `json:"accessKey,omitempty"`
SecretKey string `json:"secretKey,omitempty"`
}
SecureJSONData is a representation of the datasource `secureJsonData` property
Click to show internal directories.
Click to hide internal directories.